package org.jdtaus.core.messages;

import java.util.HashMap;
import java.util.Map;
import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

abstract class ExceptionMessageBundle{ 

/** <pre> An {1} occured.
{2}</pre>. */
public static String getThrowableInfoText(final Locale locale) {
    return getMessage("throwableInfo", locale);
}

/** <pre> An {1} occured.
{2}</pre>. */
public static MessageFormat getThrowableInfoMessage(Locale locale) {
    if(locale == null) { locale = Locale.getDefault(); }
return new MessageFormat(getMessage("throwableInfo", locale), locale);
}

/** <pre> No details available.</pre>. */
public static String getNullMessageText(final Locale locale) {
    return getMessage("nullMessage", locale);
}

/** <pre> No details available.</pre>. */
public static MessageFormat getNullMessageMessage(Locale locale) {
    if(locale == null) { locale = Locale.getDefault(); }
return new MessageFormat(getMessage("nullMessage", locale), locale);
}

private static final Map cache = new HashMap();

private static String getMessage(final String key, Locale locale) {
    if(locale == null) {locale = Locale.getDefault(); }
    Map msgCache = (Map) cache.get(locale);
    if(msgCache == null)
    {
        msgCache = new HashMap();
        cache.put(locale, msgCache);
    }

    String msg = (String) msgCache.get(key);
    if(msg == null)
    {
        msg = ResourceBundle.getBundle(
        "org.jdtaus.core.messages.ExceptionMessage", locale).getString(key);
        msgCache.put(key, msg);
    };
    return msg;
}

}
